@@ -16,7 +16,7 @@ use constant IS_CYGWIN => $^O =~ /cygwin/i;
 use constant IS_WIN32ish => &IS_WIN32 || &IS_CYGWIN;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name shquote
 		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl DEVNULL DEVTTY);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -108,7 +108,7 @@ sub isValidPid {
         # v0.94 raised FIRST_DEFERRED_ID from -500_000 to -1_100_000
         #
 	# also see &Forks::Super::Deferred::FIRST_DEFERRED_ID
-	return $pid > 0 || ($pid > -1000000 && $pid <= -2);
+	return $pid > 0 || ($pid > -2_000_000 && $pid <= -2);
     } else {
 	return $pid > 0;
     }
@@ -397,7 +397,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 
 =head1 VERSION
 
-0.94
+0.95
 
 =head1 SYNOPSIS
 
